==> confixx_3.3.1.orig.tar.gz: confixx-3.3.1.orig/html/ftplogin/title.php <==
<?
########## Confixx(R) 3.0 Professional ############
####### Copyright SWsoft, Inc. 2004-2005 ##########
#### http://www.sw-soft.com - info@sw-soft.com ####

include_once("auth.php");
?>
<HTML>
<HEAD>
<META content="text/html; charset=<? echo $lang_html_charset; ?>" http-equiv=Content-Type>
<LINK href="<?=$strSkinName?>/style.css" rel=stylesheet type=text/css>
</HEAD>
<body leftmargin=0 topmargin=0 marginwidth=0 marginheight=0 bgcolor=white>
<form Action="title.php" method="post">
<table width="100%" border=0 cellspacing=0 cellpadding=0>
        <tr>
                <td width="100%" background="<?=$strSkinName?>/pics/bg_middle.jpg">
                        <table width="100%" border=0 cellspacing=0 cellpadding=0>
                                <tr>
                                        <td valign=top><img src="<?=$strSkinName?>/pics/confixx_logo.jpg" width=218 height=77></td>
<script>
function over(number) {
  document.images["image"+number+"_1"].src='<?=$strSkinName?>/pics/buttons/bt_left_mover.jpg';
  document.images["image"+number+"_2"].src='<?=$strSkinName?>/pics/buttons/bt_right_mover.jpg';
  if (document.layers) {
    document.layers["m"+number].background.src='<?=$strSkinName?>/pics/buttons/bt_mid_mover.jpg';
  }
  else if (document.all) {
    window.document.all["id"+number].style.background = 'url(<?=$strSkinName?>/pics/buttons/bt_mid_mover.jpg)';
  }
  else if(a = document.getElementById("id"+number))
  {
    a.style.background = 'url(<?=$strSkinName?>/pics/buttons/bt_mid_mover.jpg)';
  }
}
function out(number) {
  document.images["image"+number+"_1"].src='/1x1.gif';
  document.images["image"+number+"_2"].src='/1x1.gif';
  if (document.layers) {
    document.layers["m"+number].background.src='/1x1.gif';
  }
  else if (document.all) {
    window.document.all["id"+number].style.background = 'url(/1x1.gif)';
  }
  else if(a = document.getElementById("id"+number))
  {
    a.style.background = 'url(/1x1.gif)';
  }
}

</script>

<? function menu($text,$menu,$browser) {
if ($browser == 0) { ?>
<td><img src=/1x1.gif width=1 height=45><br>
<table width="100%" border=0 cellspacing=0 cellpadding=0 class=button>
<tr>
<td valign=top><a href="menu.php?num=<?=$menu?>" target=menu class="button" onmouseover=over(<?=$menu?>); onmouseout=out(<?=$menu?>);><img src="/1x1.gif" width=8 height=18 name="image<?=$menu?>_1" border=0></a></td>
<td width="100%" id="id<?=$menu?>" valign=center nowrap class="button-1" height=20><ilayer top=-1 name=m<?=$menu?> background="/1x1.gif"><img src=/1x1.gif height=14 width=1><a href="menu.php?num=<?=$menu?>" target=menu class="button-1" onmouseover=over(<?=$menu?>); onmouseout=out(<?=$menu?>);><?=$text?></a></ilayer></td>
<td valign=top><a href="menu.php?num=<?=$menu?>" target=menu class="button" onmouseover=over(<?=$menu?>); onmouseout=out(<?=$menu?>); ><img src="/1x1.gif" width=8 height=18 name="image<?=$menu?>_2" border=0></a></td>
</tr>
</table>
</td>
<? } else { ?>
<td><img src=/1x1.gif width=1 height=45><br>
<table width="100%" border=0 cellspacing=0 cellpadding=0 class=button>
<tr>
<td><a target=menu href="menu.php?num=<?=$menu?>" class="button" onmouseover=over(<?=$menu?>); onmouseout=out(<?=$menu?>);><img src="/1x1.gif" width=8 height=18 name="image<?=$menu?>_1" border=0></a></td>
<td width="100%" id="id<?=$menu?>" background="<?=$strSkinName?>/pics/buttons/bt_mid_mover.jpg" nowrap class="button-1"><a href="menu.php?num=<?=$menu?>" target=menu class="button-1" onmouseover=over(<?=$menu?>); onmouseout=out(<?=$menu?>);><?=$text?></a></td>
<td><a href="menu.php?num=<?=$menu?>" target=menu target=menu class="button" onmouseover=over(<?=$menu?>); onmouseout=out(<?=$menu?>); ><img src="/1x1.gif" width=8 height=18 name="image<?=$menu?>_2" border=0></a></td>
</tr>
</table>
</td>
<? } ?>
<? } ?>

<?
$browser=0;
if (strpos($HTTP_USER_AGENT,"IE") > 0) $browser=1;
menu(ltext("m_wftp_home"),1,$browser);
if($trueftpusr == 0){menu(ltext("m_general"),2,$browser);}
if ($browser == 0) { ?>
<td><img src=/1x1.gif width=1 height=45><br>
<table width="100%" border=0 cellspacing=0 cellpadding=0 class=button>
<tr>
<td valign=top><a href="/logout.php?user=<? echo $PHP_AUTH_USER; ?>" target=_top class="button" onmouseover=over(5); onmouseout=out(5);><img src="/1x1.gif" width=8 height=18 name="image5_1" border=0></a></td>
<td width="100%" id="id5" valign=center nowrap class="button-1" height=20><ilayer top=-1 name=m5 background="/1x1.gif"><img src=/1x1.gif height=14 width=1><a href="/logout.php?user=<? echo $PHP_AUTH_USER; ?>" target=_top class="button-1" onmouseover=over(5); onmouseout=out(5);><? echo ltext("m_login"); ?></a></ilayer></td>
<td valign=top><a href="/logout.php?user=<? echo $PHP_AUTH_USER; ?>" target=_top class="button" onmouseover=over(5); onmouseout=out(5); ><img src="/1x1.gif" width=8 height=18 name="image5_2" border=0></a></td>
</tr>
</table>
</td>
<? } else { ?>
<td><img src=/1x1.gif width=1 height=45><br>
<table width="100%" border=0 cellspacing=0 cellpadding=0 class=button>
<tr>
<td><a target=_top href="/logout.php?user=<? echo $PHP_AUTH_USER; ?>" class="button" onmouseover=over(5); onmouseout=out(5);><img src="/1x1.gif" width=8 height=18 name="image5_1" border=0></a></td>
<td width="100%" id="id5" background="<?=$strSkinName?>/pics/buttons/bt_mid_mover.jpg" nowrap class="button-1"><a href="/logout.php?user=<? echo $PHP_AUTH_USER; ?>" target=_top class="button-1" onmouseover=over(5); onmouseout=out(5);><? echo ltext("m_login"); ?></a></td>
<td><a href="/logout.php?user=<? echo $PHP_AUTH_USER; ?>" target=_top class="button" onmouseover=over(5); onmouseout=out(5); ><img src="/1x1.gif" width=8 height=18 name="image5_2" border=0></a></td>
</tr>
</table>
</td>
<script>
out(5);
</script>
<? } ?>
<td valign=top>
                                                <table width="100%" border=0 cellspacing=0 cellpadding=0>
                                                        <tr>
                                                                <td><img src="<?=$strSkinName?>/pics/alpha.gif" width=10 height=48></td>
                                                        </tr>
                                                        <tr>

                                                                <td>
                                                                </td>
                                                        </tr>
                                                </table>
                                        </td>
                                        <td background="<?=$strSkinName?>/pics/bg_top_mid.jpg"><img src="<?=$strSkinName?>/pics/bg_top_curve.jpg" width=37 height=77>
                                        </td>
                                        <td width="100%" valign="top" background="<?=$strSkinName?>/pics/bg_top_mid.jpg" >
                                                <table width="100%" border=0 cellspacing=0 cellpadding=0>
                                                        <tr>
                                                                <td><img src="<?=$strSkinName?>/pics/alpha.gif" width=10 height=52>
                                                                </td>
                                                        </tr>
                                                        <tr>
                                                        </tr>
                                                </table>
                                        </td>
                                </tr>
                        </table>
                </td>

                <td valign="top"><img src="<?=$strSkinName?>/pics/bg_top_right_curve.jpg" width="12" height="77">
                </td>
        </tr>
</table>
</body>
</html>

==> confixx_3.3.3.orig.tar.gz: confixx-3.3.3.orig/html/ftplogin/title.php <==
<?
########## Confixx(R) 3.0 Professional ############
####### Copyright SWsoft, Inc. 2004-2005 ##########
#### http://www.sw-soft.com - info@sw-soft.com ####

include_once("auth.php");
?>
<HTML>
<HEAD>
<META content="text/html; charset=<? echo $lang_html_charset; ?>" http-equiv=Content-Type>
<LINK href="<?=$strSkinName?>/style.css" rel=stylesheet type=text/css>
</HEAD>
<body leftmargin=0 topmargin=0 marginwidth=0 marginheight=0 bgcolor=white>
<form Action="title.php" method="post">
<table width="100%" border=0 cellspacing=0 cellpadding=0>
        <tr>
                <td width="100%" background="<?=$strSkinName?>/pics/bg_middle.jpg">
                        <table width="100%" border=0 cellspacing=0 cellpadding=0>
                                <tr>
                                        <td valign=top><a href="http://www.parallels.com/de/products/confixx/" target="_blank"  title="<?=ltext('go_to_confixx')?>"><img src="<?=$strSkinName?>/pics/confixx_logo.jpg" width=218 height=77 border="0"></a></td>
<script>
function over(number) {
  document.images["image"+number+"_1"].src='<?=$strSkinName?>/pics/buttons/bt_left_mover.jpg';
  document.images["image"+number+"_2"].src='<?=$strSkinName?>/pics/buttons/bt_right_mover.jpg';
  if (document.layers) {
    document.layers["m"+number].background.src='<?=$strSkinName?>/pics/buttons/bt_mid_mover.jpg';
  }
  else if (document.all) {
    window.document.all["id"+number].style.background = 'url(<?=$strSkinName?>/pics/buttons/bt_mid_mover.jpg)';
  }
  else if(a = document.getElementById("id"+number))
  {
    a.style.background = 'url(<?=$strSkinName?>/pics/buttons/bt_mid_mover.jpg)';
  }
}
function out(number) {
  document.images["image"+number+"_1"].src='/1x1.gif';
  document.images["image"+number+"_2"].src='/1x1.gif';
  if (document.layers) {
    document.layers["m"+number].background.src='/1x1.gif';
  }
  else if (document.all) {
    window.document.all["id"+number].style.background = 'url(/1x1.gif)';
  }
  else if(a = document.getElementById("id"+number))
  {
    a.style.background = 'url(/1x1.gif)';
  }
}

</script>

<? function menu($text,$menu,$browser) {
if ($browser == 0) { ?>
<td><img src=/1x1.gif width=1 height=45><br>
<table width="100%" border=0 cellspacing=0 cellpadding=0 class=button>
<tr>
<td valign=top><a href="menu.php?num=<?=$menu?>" target=menu class="button" onmouseover=over(<?=$menu?>); onmouseout=out(<?=$menu?>);><img src="/1x1.gif" width=8 height=18 name="image<?=$menu?>_1" border=0></a></td>
<td width="100%" id="id<?=$menu?>" valign=center nowrap class="button-1" height=20><ilayer top=-1 name=m<?=$menu?> background="/1x1.gif"><img src=/1x1.gif height=14 width=1><a href="menu.php?num=<?=$menu?>" target=menu class="button-1" onmouseover=over(<?=$menu?>); onmouseout=out(<?=$menu?>);><?=$text?></a></ilayer></td>
<td valign=top><a href="menu.php?num=<?=$menu?>" target=menu class="button" onmouseover=over(<?=$menu?>); onmouseout=out(<?=$menu?>); ><img src="/1x1.gif" width=8 height=18 name="image<?=$menu?>_2" border=0></a></td>
</tr>
</table>
</td>
<? } else { ?>
<td><img src=/1x1.gif width=1 height=45><br>
<table width="100%" border=0 cellspacing=0 cellpadding=0 class=button>
<tr>
<td><a target=menu href="menu.php?num=<?=$menu?>" class="button" onmouseover=over(<?=$menu?>); onmouseout=out(<?=$menu?>);><img src="/1x1.gif" width=8 height=18 name="image<?=$menu?>_1" border=0></a></td>
<td width="100%" id="id<?=$menu?>" background="<?=$strSkinName?>/pics/buttons/bt_mid_mover.jpg" nowrap class="button-1"><a href="menu.php?num=<?=$menu?>" target=menu class="button-1" onmouseover=over(<?=$menu?>); onmouseout=out(<?=$menu?>);><?=$text?></a></td>
<td><a href="menu.php?num=<?=$menu?>" target=menu target=menu class="button" onmouseover=over(<?=$menu?>); onmouseout=out(<?=$menu?>); ><img src="/1x1.gif" width=8 height=18 name="image<?=$menu?>_2" border=0></a></td>
</tr>
</table>
</td>
<? } ?>
<? } ?>

<?
$browser=0;
if (strpos($HTTP_USER_AGENT,"IE") > 0) $browser=1;
menu(ltext("m_wftp_home"),1,$browser);
if($trueftpusr == 0){menu(ltext("m_general"),2,$browser);}
if ($browser == 0) { ?>
<td><img src=/1x1.gif width=1 height=45><br>
<table width="100%" border=0 cellspacing=0 cellpadding=0 class=button>
<tr>
<td valign=top><a href="/logout.php?user=<? echo $PHP_AUTH_USER; ?>" target=_top class="button" onmouseover=over(5); onmouseout=out(5);><img src="/1x1.gif" width=8 height=18 name="image5_1" border=0></a></td>
<td width="100%" id="id5" valign=center nowrap class="button-1" height=20><ilayer top=-1 name=m5 background="/1x1.gif"><img src=/1x1.gif height=14 width=1><a href="/logout.php?user=<? echo $PHP_AUTH_USER; ?>" target=_top class="button-1" onmouseover=over(5); onmouseout=out(5);><? echo ltext("m_login"); ?></a></ilayer></td>
<td valign=top><a href="/logout.php?user=<? echo $PHP_AUTH_USER; ?>" target=_top class="button" onmouseover=over(5); onmouseout=out(5); ><img src="/1x1.gif" width=8 height=18 name="image5_2" border=0></a></td>
</tr>
</table>
</td>
<? } else { ?>
<td><img src=/1x1.gif width=1 height=45><br>
<table width="100%" border=0 cellspacing=0 cellpadding=0 class=button>
<tr>
<td><a target=_top href="/logout.php?user=<? echo $PHP_AUTH_USER; ?>" class="button" onmouseover=over(5); onmouseout=out(5);><img src="/1x1.gif" width=8 height=18 name="image5_1" border=0></a></td>
<td width="100%" id="id5" background="<?=$strSkinName?>/pics/buttons/bt_mid_mover.jpg" nowrap class="button-1"><a href="/logout.php?user=<? echo $PHP_AUTH_USER; ?>" target=_top class="button-1" onmouseover=over(5); onmouseout=out(5);><? echo ltext("m_login"); ?></a></td>
<td><a href="/logout.php?user=<? echo $PHP_AUTH_USER; ?>" target=_top class="button" onmouseover=over(5); onmouseout=out(5); ><img src="/1x1.gif" width=8 height=18 name="image5_2" border=0></a></td>
</tr>
</table>
</td>
<script>
out(5);
</script>
<? } ?>
<td valign=top>
                                                <table width="100%" border=0 cellspacing=0 cellpadding=0>
                                                        <tr>
                                                                <td><img src="<?=$strSkinName?>/pics/alpha.gif" width=10 height=48></td>
                                                        </tr>
                                                        <tr>

                                                                <td>
                                                                </td>
                                                        </tr>
                                                </table>
                                        </td>
                                        <td background="<?=$strSkinName?>/pics/bg_top_mid.jpg"><img src="<?=$strSkinName?>/pics/bg_top_curve.jpg" width=37 height=77>
                                        </td>
                                        <td width="100%" valign="top" background="<?=$strSkinName?>/pics/bg_top_mid.jpg" >
                                                <table width="100%" border=0 cellspacing=0 cellpadding=0>
                                                        <tr>
                                                                <td><img src="<?=$strSkinName?>/pics/alpha.gif" width=10 height=52>
                                                                </td>
                                                        </tr>
                                                        <tr>
                                                        </tr>
                                                </table>
                                        </td>
                                </tr>
                        </table>
                </td>

                <td valign="top"><img src="<?=$strSkinName?>/pics/bg_top_right_curve.jpg" width="12" height="77">
                </td>
        </tr>
</table>
</body>
</html>
